@@ -11,53 +11,54 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
 
   nu <- integer(length(n.var))
 
-  ord.fac <- FALSE
-  for (i in 1:n.var) if (class(data[,i])[1] == "ordered") ord.fac <- TRUE
-
-  chr.flg <- FALSE
-  for (i in 1:n.var) if (class(data[,i])[1] == "character") chr.flg <- TRUE
-
 
   if (!brief) {
-    cat("\n")
-    cat("Basics\n")
-    .dash(47)
-    cat("Number of Variables in the data frame:    ", n.var, "\n", sep="")
-    cat("Number of Rows of Data in the data frame: ", n.obs, "\n", sep="")
-    .dash(47)
+    cat("Dimensions:", n.var, "variables over", n.obs, "rows of data")
 
     cat("\n\n")
-    cat("Row Names\n")
-    .dash(67)
     cat("First two row names:", row.names(data)[1],"   ", 
         row.names(data)[2], "\n") 
     cat("Last two row names: ", row.names(data)[n.obs-1],
         "   ", row.names(data)[n.obs], "\n") 
-    .dash(67)
-  }
+    .dash(58)
+    cat("\n")
 
-  cat("\n")
-  if (!brief) cat("\n")
-  cat("Variable Names and Data Types\n")
-  if (!brief) {
-    .dash(70)
-    cat("factor: Non-numeric categories, initially read as unordered categories\n")
+    reg.fac <- FALSE
+    for (i in 1:n.var) if (class(data[,i])[1] == "factor") reg.fac <- TRUE
+
+    ord.fac <- FALSE
+    for (i in 1:n.var) if (class(data[,i])[1] == "ordered") ord.fac <- TRUE
+
+    chr.flg <- FALSE
+    for (i in 1:n.var) if (class(data[,i])[1] == "character") chr.flg <- TRUE
+
+    cat("\n")
+    cat("Data Types\n")
+    .dash(60)
+    if (reg.fac) cat("factor: Non-numeric categories, read as unordered categories\n")
     if (ord.fac) cat("ordfact: Ordered, non-numeric categories\n")
     if (chr.flg) cat("character: Non-numeric unique values\n")
-    cat("integer: The data values are numeric but integers only\n")
-    cat("numeric: The data values are numeric with decimal digits\n")
+    cat("integer: Numeric data values, but integers only\n")
+    cat("numeric: Numeric data values with decimal digits\n")
+    .dash(60)
   }
+  cat("\n")
+
+  #if (any(is.na(mydata)))
+    #cat("NA indicates a missing data value, Not Available\n")
+  #cat("\n")
 
-  .dash(70)
   max.char <- 0
   for (i in 1:n.var) {
     x.name <- names(data)[i]
     if (nchar(x.name) > max.char) max.char <- nchar(x.name)
   }
   pad <- ifelse (max.char > 7, max.char + 2, max.char + (10-max.char))
+  pad2 <- ifelse (max.char > 8, max.char - 8, 0)
   if (!brief) cat("\n")
-  cat(.fmtc(" ",pad+16), .fmtc("Missing",6), .fmtc("Unique",7), "\n")
-  cat(.fmtc(" Variable",max.char+1), .fmtc("Type",8), .fmtc("Values",7),
+  cat(.fmtc(" Variable",9+pad2), .fmtc(" ",pad2+(16-pad2)),
+      .fmtc("Missing",7), .fmtc("Unique",7), "\n")
+  cat(.fmtc("     Name",max.char+1), .fmtc("Type",8), .fmtc("Values",7),
       .fmtc("Values",7), .fmtc("Values",7), "  First and last values\n")
   .dash(88)
 
@@ -105,13 +106,13 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
   if (!brief) {
     if (colm.ID > 0) {
       cat("\n\n")
-      cat("For the following 'variable', each row of data is unique. Perhaps\n",
-          "these values specify a unique ID for each row. To implement, re-read\n",
-          "with the following setting added to your Read statement: row.names=", 
+      cat("For the following 'variable', each row of data is unique. Do these values\n",
+          "specify a unique ID for each row? To implement, re-read (if a text or Excel\n",
+          "file) with the following setting added to your Read statement: row.names=", 
           toString(colm.ID), sep="", "\n")
-      .dash(70)
+      .dash(75)
       cat(maybe.ID, "\n")
-      .dash(70)
+      .dash(75)
     }
 
     n.cat <- getOption("n.cat")
@@ -122,12 +123,13 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
     }
     if (int.cat) {
       cat("\n\n")
-      cat("Each of these variables is numeric, but has less than or equal\n", 
-         n.cat.temp, " unique values. If these variables are categorical consider to\n",
-         "transform each variable into a factor with the Transform and\n",
-         "factor functions. To see examples enter:  > ?Transform\n", 
-         "Or, specify a value for n.cat, ",
-         "such as:  > set(n.cat=4)\n", sep="")
+      cat("Each of these variables has numeric values, but has less than ",
+          n.cat.temp, "\n",
+          "unique values. Perhaps these variables are categorical. Consider\n",
+          "to transform each variable into a factor with the Transform and\n",
+          "factor functions. To see examples enter:  > ?Transform\n", 
+          "Or, specify a value for n.cat, ",
+          "such as:  > set(n.cat=4)\n", sep="")
       .dash(63)
       for (j in 1:n.var) if (is.numeric(data[,j]) && nu[j] <= n.cat.temp)
         cat(names(data)[j], "\n")
@@ -135,12 +137,12 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
     }
     
     cat("\n\n")
-    cat("Missing Data Analysis\n")
-    .dash(52)
 
     n.miss.tot <- sum(is.na(data))
     
     if (n.miss.tot > 0) {
+      cat("Missing Data Analysis\n")
+      .dash(52)
       
       cat("n.miss ", "Observation\n")
       n.lines <- 0
@@ -154,10 +156,8 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
         }
         if (n.lines == miss.show) {
           n.lines <- -1
-          cat("\nToo many data rows have at least this many missing values: ", n.mcut, "\n",
-            "No more lines displayed to conserve space.\n",
+          cat("\nMore data rows have at least this many missing values: ", n.mcut, "\n",
             "Specify n.mcut=2 to see just those lines with 2 missing values, etc,",
-            "or use a higher number.\n",
             "Or increase the default value of miss.show=30 to show more lines.\n")
         }
       }
@@ -184,20 +184,23 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
   if (brief) cat("\n")
   mylabels <- attr(data, which="variable.labels")
   myunits <- attr(data, which="variable.units")
-  cat("\nVariable Names   Variable Labels\n")
 
   if (!is.null(mylabels)) {
+    cat("\nVariable Names   Variable Labels\n")
     n.rows <- length(mylabels)
     n.lines <- min(max.lines, n.rows)
 
     mx.nm <- 0
-    for (i in 1:n.lines)  # var names
-      if (nchar(names(mylabels)[i]) > mx.nm) mx.nm <- nchar(names(mylabels)[i])
+    for (i in 1:n.lines) {  # width of var names
+      if (!is.na(mylabels[i])) if (nchar(names(mylabels)[i]) > mx.nm)
+        mx.nm <- nchar(names(mylabels)[i])
+    }
     width.nm <- mx.nm + 1
 
     mx.ln <- 0
+    nc <- 0
     for (i in 1:n.lines) {  # get width of largest line
-      nc <- nchar(as.character(mylabels[i]))
+      if (!is.na(mylabels[i])) nc <- nchar(as.character(mylabels[i]))
       if (nc > mx.ln) mx.ln <- mx.nm + nc
     }
     width.ln <- max(mx.ln, nchar("Variable Names  Variable Labels"))
@@ -214,23 +217,24 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
     if (n.rows > n.lines) {
       cat("To see all the variable labels set mx.lines to", n.rows, "\n")
       .dash(64)
-      cat("\n")
     }
   }
-  else {
-    .dash(64)
-    cat("None\n")
-  }
+  else
+    cat("No variable labels\n")
+
+    cat("\n")
+
 
   # feedback regarding variable units
-  cat("\n\nVariable Names   Variable Units\n")
 
   if (!is.null(myunits)) {
+    cat("\nVariable Names   Variable Units\n")
     n.units <- length(myunits)
     n.lines <- min(max.lines, n.units)
 
+    width.ln <- width.nm
     for (i in 1:n.lines)  # get width of largest line
-      width.ln <- width.nm + nchar(as.character(myunits[i]))
+      if (!is.na(myunits[i])) width.ln <- width.nm + nchar(as.character(myunits[i]))
     width.ln <- max(width.ln, 1+nchar("Variable Names  Variable Units"))
 
     .dash(width.ln)
@@ -241,10 +245,8 @@ function(data=mydata, n.mcut=1, miss.zero=FALSE, max.lines=30,
     }
     .dash(width.ln)
   }
-  else {
-    .dash(64)
-    cat("None\n")
-  }
+  else
+    cat("No variable units\n")
 
   cat("\n")
 }
